#!/bin/sh 

# slay_vca shell script

# Signal handler.
SignalTrap()
{
	echo "Received signal.  Update aborting."
	exit 1
}

# Write to PAS_LOG
function log
{
	# Remember whether nslogutil is available
	if [ "$LOGUTIL_TEST" = "" ]; then
		which nslogutil
		LOGUTIL_TEST=$?
	fi
	if [ $LOGUTIL_TEST -eq 0 ]; then
		nslogutil -p "$1" > /dev/null
	else
		echo "$1"
	fi
}

# Set Signal Trap
trap SignalTrap INT QUIT TERM ABRT STOP

function check_cleanup_preconditions
{
	# version number for R10RC1 and R10RC2 releases"
	local R10RC1="3.4.22251"
	local R10RC2="3.4.23088"
	local SIZE_50MB=$((50*1024))	# 50MB represented in KB
	
	# version installed on SYNC module
	local sw_version=$(grep "SYNCGen3" /fs/mp/Version.inf | awk -F_ '{print $2}')
	log "CLEAN_SLOGS_UTIL: sw version=${sw_version}"
	
	# spaced used by slogs folder
	local slog_size=0
	if [[ -d /fs/rwdata/slogs ]]
	then
		slog_size="$(du -sk /fs/rwdata/slogs | awk '{print $1}')"
		log "CLEAN_SLOGS_UTIL: size of slogs folder: ${slog_size} KB"
	fi
	
	# proceed to clean slogs only if version is either of R10RC1 or R10RC2 or slogs size is more than 50MB
	if [[ $sw_version == $R10RC1 || $sw_version == $R10RC2 || $slog_size -gt $SIZE_50MB ]]
	then
		return 1
	else
		return 0
	fi
}

function clean_slogs
{
	check_cleanup_preconditions
	if [[ $? == 0 ]]
	then
		log "CLEAN_SLOGS_UTIL: Preconditions not met. Exiting..."
		return
	fi
	
	# Delete all files in /fs/rwdata/slogs, except the current boot.
	if [[ -d /fs/rwdata/slogs ]]
	then
		success=0
		slog_size="$(du -sk /fs/rwdata/slogs)"
		rwdata_size="$(du -sk /fs/rwdata)"

		for attempt in 1 2 3
		do
			# find all files in slogs folder except the one in current use
			files=$(find /fs/rwdata/slogs -type f ! -name ${BOOT_COUNT}.slog)
			count=$(echo ${files} | wc -w)
			# if files list is empty then print message and exit
			if [[ -z ${files} ]]
			then
				# No files to delete. /fs/rwdata/slogs is not hogging disk space.
				log "CLEAN_SLOGS_UTIL: No files to delete. Exiting..."
				return
			else
				rm -f ${files}
				retCode=$?
				if [[ ${retCode} -eq 0 ]]
				then
					success=1
					log "CLEAN_SLOGS_UTIL: Deleted ${count} files."
					break;
				fi
			fi
		done
		
		if [[ ${success} -eq 1 ]]
		then
			log "CLEAN_SLOGS_UTIL: Files deleted successfully in ${attempt} attempt(s)."
		else
			log "CLEAN_SLOGS_UTIL: Failed to delete files after 3 retries. Error: ${retCode}"
		fi
			
		# Print summary:
		log "CLEAN_SLOGS_UTIL: Disk usage before(in KB):"
		log "CLEAN_SLOGS_UTIL: ${slog_size}"
		log "CLEAN_SLOGS_UTIL: ${rwdata_size}"
		log "CLEAN_SLOGS_UTIL: Disk usage after(in KB):"
		log "CLEAN_SLOGS_UTIL: $(du -sk /fs/rwdata/slogs)"
		log "CLEAN_SLOGS_UTIL: $(du -sk /fs/rwdata)"
	else
		log "CLEAN_SLOGS_UTIL: /fs/rwdata/slogs folder does not exist. Nothing to do."
	fi
}

function slay_vca
{
	# slay VCA_Manager and remove db file
	DEVICE_DB=`grep "DEVICE_DB =" /fs/mp/etc/system/config/VCAConfig.cfg | awk {'print $3'}`
	if [ -n "$DEVICE_DB" -a -f "$DEVICE_DB" ]; then
		sqlite3 $DEVICE_DB "select deviceId, count(*) from DBofDBs group by deviceId having count(*) > 1" 2>&1 | grep -Eq "malformed|\|"
		if [ $? -eq 0 ]; then
			log "SLAY_VCA_UTIL: VCA device db error state detected; slaying VCA_Manager."
			# send signal SIGKILL to VCA_Manager
			slay -9 VCA_Manager
			rm -f $DEVICE_DB
			sync
			sync
		else
			log "SLAY_VCA_UTIL: VCA device db error state not detected."
		fi
	else
		log "SLAY_VCA_UTIL: Could not get DEVICE_DB location."
	fi
}

# Function calls.
clean_slogs
slay_vca
exit 0
